﻿using System;
using System.Collections.Generic;
using System.Collections.ObjectModel;
using System.ComponentModel;
using System.Data;
using System.Linq;
using System.Text;
using System.Windows.Forms;

using MindFusion.Charting;
using MindFusion.Charting.Components;
using MindFusion.Charting.WinForms;
using MindFusion.Drawing;

using Color = System.Drawing.Color;


namespace PrintAndExport
{
	public partial class MainForm : Form
	{
		public MainForm()
		{
			InitializeComponent();

			chart.Title = "Print and Export Sample";
			chart.Subtitle = "by MindFusion";

			// create sample data
			List<double> months = new List<double>();
			for(int i = 1; i <= 11; i++)
				months.Add(i);

			Random rand = new Random();
			chart.Series.Add(
				new Series2D(months,
					GenerateEvaluationList(rand),
					new List<string>
					{
						"January", "February", "March", "April", "May", "June", "July",
						"August", "September", "Octomber", "November"
					})
					{
						Title = "1 Grade"
					});
			chart.Series.Add(
				new Series2D(months, GenerateEvaluationList(rand), null)
				{
					Title = "2 Grade"
				});
			chart.Series.Add(
				new Series2D(months, GenerateEvaluationList(rand), null)
				{
					Title = "3 Grade"
				});

			// set axis ranges
			chart.XAxis.MinValue = 0;
			chart.XAxis.Interval = 1;
			chart.YAxis.MinValue = 0;
			chart.YAxis.Interval = 1;

			chart.GridType = GridType.Crossed;
			chart.Theme.GridLineStyle = System.Drawing.Drawing2D.DashStyle.Dash;
			
			// specify appearance through Theme
			chart.Theme = new Theme
			{
				CommonSeriesFills = new List<Brush>
                {
                    new SolidBrush(Color.FromArgb(102, 154, 204)),
                    new SolidBrush(Color.FromArgb(0, 52, 102)),
                    new SolidBrush(Color.FromArgb(206, 0, 0))
                },
				UniformSeriesFill = new SolidBrush(Color.Red),
				UniformSeriesStrokeThickness = 2
			};
		}

		private void btnPrint_Click(object sender, EventArgs e)
		{
			chart.Print();
		}

		private void btnPrintWithPreview_Click(object sender, EventArgs e)
		{
			chart.PrintPreview();	
		}

		private void btnExportToPdf_Click(object sender, EventArgs e)
		{
			SaveFileDialog dlg = new SaveFileDialog();
			dlg.Filter = "(PDF *.pdf)|*.pdf";
			var result = dlg.ShowDialog();
			if (result == DialogResult.OK)
			{
				chart.ExportPdf(dlg.FileName);
			}
		}

		private void btnExportToSvg_Click(object sender, EventArgs e)
		{
			var dlg = new SaveFileDialog();
			dlg.Filter = "(SVG *.svg)|*.svg";
			var result = dlg.ShowDialog();
			if (result == DialogResult.OK)
			{
				chart.ExportSvg(dlg.FileName);
			}
		}

		private void btnExportToImage_Click(object sender, EventArgs e)
		{
			var dlg = new SaveFileDialog();
			dlg.Filter = "(BMP *.bmp)|*.bmp";
			var result = dlg.ShowDialog();
			if (result == DialogResult.OK)
			{
				chart.ExportImage(dlg.FileName);
			}
		}

		private List<double> GenerateEvaluationList(Random rand)
		{
			var averageEvaluation = new List<double>();
			for (int i = 1; i <= 11; i++)
				averageEvaluation.Add(rand.Next(2, 6) + rand.NextDouble());
			return averageEvaluation;
		}
	}
}